import org.camunda.bpm.client.ExternalTaskClient;
import org.camunda.bpm.client.task.ExternalTask;
import org.camunda.bpm.client.task.ExternalTaskHandler;
import org.camunda.bpm.client.task.ExternalTaskService;
import java.sql.*;
import java.util.HashMap;
import java.util.Map;

public class MembershipValidationWorker {

    public void MembershipValidationWorkerRun() {
        System.out.println(this.getClass().getName() + " Started");

        // Load the H2 JDBC driver
        try {
            Class.forName("org.h2.Driver");
        } catch (ClassNotFoundException e) {
            System.out.println("H2 JDBC Driver not found: " + e.getMessage());
            return; // Exit if the driver is not found
        }

        // Initialize the Camunda External Task Client
        ExternalTaskClient client = ExternalTaskClient.create()
                .baseUrl("http://localhost:8080/engine-rest")
                .asyncResponseTimeout(10000) // Timeout for long polling
                .build();

        // Subscribe to the "membership_validation_worker" topic
        client.subscribe("membership_validation_worker")
                .lockDuration(1000) // Lock duration in milliseconds
                .handler(new ExternalTaskHandler() {
                    @Override
                    public void execute(ExternalTask externalTask, ExternalTaskService externalTaskService) {
                        try {
                            // Extract variables from the task and convert member_id to int
                            Integer memberId = Integer.parseInt(externalTask.getVariable("member_id").toString());
                            String password = (String) externalTask.getVariable("password");

                            // Validate membership using the H2 database
                            boolean isValid = validateMembership(memberId, password);

                            // Prepare variables for response
                            Map<String, Object> variables = new HashMap<>();
                            variables.put("isValid", isValid);

                            // Complete the task and set the result variable
                            externalTaskService.complete(externalTask, variables);

                            System.out.println("Processed task for memberId: " + memberId);
                        } catch (Exception e) {
                            System.out.println("Error processing task: " + e.getMessage());
                        }
                    }
                }).open();
    }

    // Connect to the H2 database and validate the username/password
    private static boolean validateMembership(Integer memberId, String password) {
        boolean isValid = false;

        String sql = "SELECT * FROM members WHERE MEMBER_ID = ? AND PASSWORD = ? AND IS_ACTIVE = TRUE";

        try (Connection conn = DatabaseConfig.getConnection();
             PreparedStatement stmt = conn.prepareStatement(sql)) {

            stmt.setInt(1, memberId); // Use setInt for integer parameter
            stmt.setString(2, password);

            try (ResultSet rs = stmt.executeQuery()) {
                if (rs.next()) {
                    isValid = true;
                    System.out.println("Database query successful: Member ID " + memberId + " is valid.");
                } else {
                    System.out.println("Database query successful: Member ID " + memberId + " is not valid.");
                }
            }

        } catch (SQLException e) {
            System.out.println("Database error: " + e.getMessage());
        }

        return isValid;
    }
}
