import org.camunda.bpm.client.ExternalTaskClient;
import org.camunda.bpm.client.task.ExternalTask;
import org.camunda.bpm.client.task.ExternalTaskHandler;
import org.camunda.bpm.client.task.ExternalTaskService;
import java.sql.*;
import java.util.HashMap;
import java.util.Map;

public class UserRegistrationWorker {

    public void UserRegistrationWorkerRun() {
        System.out.println(this.getClass().getName() + " Started");

        // Initialize the Camunda External Task Client
        ExternalTaskClient client = ExternalTaskClient.create()
                .baseUrl("http://localhost:8080/engine-rest")
                .asyncResponseTimeout(10000) // Timeout for long polling
                .build();

        // Subscribe to the "user_registration_worker" topic
        client.subscribe("user_registration_worker")
                .lockDuration(1000) // Lock duration in milliseconds
                .handler(new ExternalTaskHandler() {
                    @Override
                    public void execute(ExternalTask externalTask, ExternalTaskService externalTaskService) {
                        try {
                            // Extract variables from the task
                            String username = (String) externalTask.getVariable("username");
                            String password = (String) externalTask.getVariable("password");

                            // Register the user in the database
                            boolean isRegistered = registerUser(username, password);

                            // Prepare variables for response
                            Map<String, Object> variables = new HashMap<>();
                            variables.put("isRegistered", isRegistered);

                            // Complete the task and set the result variable
                            externalTaskService.complete(externalTask, variables);

                            System.out.println("Processed task for username: " + username);
                        } catch (Exception e) {
                            // Handle the exception as needed
                        }
                    }
                }).open();
    }

    // Connect to the H2 database and register the user
    private static boolean registerUser(String username, String password) {
        boolean isRegistered = false;

        String sql = "INSERT INTO members (USERNAME, PASSWORD) VALUES (?, ?)";

        try (Connection conn = DatabaseConfig.getConnection();
             PreparedStatement stmt = conn.prepareStatement(sql)) {

            stmt.setString(1, username);
            stmt.setString(2, password);

            int rowsAffected = stmt.executeUpdate();
            isRegistered = rowsAffected > 0;
        } catch (SQLException e) {
            // Handle the exception as needed
        }

        return isRegistered;
    }
}