-- Drop all existing tables to reset the database
DROP TABLE IF EXISTS orders;
DROP TABLE IF EXISTS services;
DROP TABLE IF EXISTS members;
DROP TABLE IF EXISTS services;

-- Create members table
CREATE TABLE IF NOT EXISTS members (
                                       member_id INT AUTO_INCREMENT PRIMARY KEY,  -- Ensure the member_id is the primary key
                                       member_name VARCHAR(100),                  -- Member's full name
                                       email VARCHAR(100) UNIQUE,                 -- Unique email address
                                       username VARCHAR(50) UNIQUE,               -- Username (must be unique)
                                       password VARCHAR(255),                     -- Password (ideally hashed in real implementation)
                                       is_active BOOLEAN                          -- Account status (active or inactive)
);

-- Create services table
CREATE TABLE IF NOT EXISTS services (
                                        service_id INT AUTO_INCREMENT PRIMARY KEY, -- Service ID as primary key
                                        service_name VARCHAR(100),                 -- Service name
                                        price DECIMAL(10, 2),                      -- Service price
                                        available BOOLEAN                          -- Availability of the service (TRUE or FALSE)
);

-- Create orders table
CREATE TABLE IF NOT EXISTS orders (
                                      order_id INT AUTO_INCREMENT PRIMARY KEY,  -- Order ID as primary key
                                      member_id INT,                            -- Reference to the member who placed the order
                                      order_date TIMESTAMP DEFAULT CURRENT_TIMESTAMP, -- Timestamp of the order
                                      amount DECIMAL(10, 2),                    -- Total amount for the order
                                      status VARCHAR(50),                       -- Order status (e.g., "completed", "pending", etc.)
                                      FOREIGN KEY (member_id) REFERENCES members(member_id) -- Foreign key to members
);

-- Create order_services table
CREATE TABLE IF NOT EXISTS order_services (
                                              order_service_id INT AUTO_INCREMENT PRIMARY KEY,   -- Unique ID for each service in an order
                                              order_id INT,                                      -- Foreign key to the orders table
                                              service_id INT,                                    -- Foreign key to the services table
                                              FOREIGN KEY (order_id) REFERENCES orders(order_id) ON DELETE CASCADE,  -- Foreign key to orders
                                              FOREIGN KEY (service_id) REFERENCES services(service_id) ON DELETE CASCADE, -- Foreign key to services
                                              CONSTRAINT unique_order_service UNIQUE(order_id, service_id) -- Ensure an order can have a specific service only once
);

-- Create the services table
CREATE TABLE IF NOT EXISTS services (
                                        service_id INT AUTO_INCREMENT PRIMARY KEY,  -- Service ID as primary key
                                        service_name VARCHAR(100),                  -- Service name
                                        price DECIMAL(10, 2),                       -- Price for the service (between 100 and 200)
                                        available BOOLEAN                           -- Availability of the service
);
-- Optionally, insert sample data after creating the tables

-- Insert sample members
INSERT INTO members (member_name, email, username, password, is_active)
VALUES
    ('John Doe', 'john@example.com', 'john_doe', 'Dilshan', TRUE),
    ('Jane Smith', 'jane@example.com', 'jane_smith', 'password123', FALSE);

-- Insert sample services
INSERT INTO services (service_name, price, available)
VALUES
    ('Basic Cleaning', 50.00, TRUE),
    ('Premium Cleaning', 100.00, FALSE);

-- Insert sample orders
INSERT INTO orders (member_id, service_id, amount)
VALUES
    (1, 1, 50.00),
    (1, 1, 50.00);

-- Insert services into the services table with prices between 100 and 200
INSERT INTO services (service_name, price, available)
VALUES
    ('Service 01', 100.00, TRUE),  -- ID 1, price 100
    ('Service 02', 120.00, TRUE),  -- ID 2, price 120
    ('Service 03', 150.00, FALSE), -- ID 3, price 150
    ('Service 04', 180.00, TRUE),  -- ID 4, price 180
    ('Service 05', 200.00, TRUE);  -- ID 5, price 200
