import { Client, logger, Variables } from "camunda-external-task-client-js";

// 配置客户端
const config = { baseUrl: "http://localhost:8080/engine-rest", use: logger };

// 创建客户端实例
const client = new Client(config);

// 订阅主题 
client.subscribe("Car_final_offer_list5", async function ({ task, taskService }) {

    const variables_ = new Variables();
    const datetime = task.variables.get("datetime");
    const id = task.variables.get("id");
    const headstock = task.variables.get("headstock");
    const body = task.variables.get("body");
    const tailstock = task.variables.get("tailstock");
    const engine = task.variables.get("engine");
    const saddle = task.variables.get("saddle");
    const operating = task.variables.get("operating");
    const additional_services = task.variables.get("additional_services");
    const confirmation = task.variables.get("confirmation");

    let total_cost = 0;  // 总费用变量

    // 定义每个选项的费用
    const priceMapping = {
        "good": 0,
        "normal": 500,
        "bad": 1000
    };

    // 计算各部件的费用
    total_cost += priceMapping[headstock] || 0;
    total_cost += priceMapping[body] || 0;
    total_cost += priceMapping[tailstock] || 0;
    total_cost += priceMapping[engine] || 0;
    total_cost += priceMapping[saddle] || 0;
    total_cost += priceMapping[operating] || 0;

    // 如果有额外服务，则加上额外费用（例如500元）
    if (additional_services === "yes") {
        total_cost += 500;  // 假设额外服务增加500元
    }

    console.log(`Ticket details: 
    - DateTime: ${datetime} 
    - Id: ${id}
    - Headstock: ${headstock} 
    - Body: ${body} 
    - Tailstock: ${tailstock} 
    - Engine: ${engine} 
    - Saddle: ${saddle} 
    - Operating: ${operating} 
    - Additional Services: ${additional_services}
    - Customer Confirmation:${confirmation}
    - Total Maintenance Cost: ${total_cost}`);

    // 设置任务变量
    variables_.set("total_cost", total_cost);  // 将总费用值添加到任务变量中

    // 完成任务
    await taskService.complete(task, variables_);
});
